# ------------------------------------------------------------------------------
#
#   Anton Synytsia
#   anton.synytsia@gmail.com
#
# ------------------------------------------------------------------------------

Sketchup.require 'ams_Lib/core.rb'
AMS::Lib.require_all

# Sketchup Window Observer example
class AMS::Examples::SWO

  def initialize
    @state = false
  end

  attr_reader :state

  # Called when the observer is added.
  def swo_activate
    puts "activate"
    @state = true
  end


  # Called when the observer is removed. The observer is removed either because
  # of an error in one of the callback methods, or because user called
  # AMS::Sketchup.remove_observer(obj) method.
  def swo_deactivate
    puts "deactivate"
    @state = false
  end


  # Called when the main window is assigned a new title text.
  # @param [String] text The new title text
  def swo_mw_onCaptionChanged(text)
    puts "swo_mw_onCaptionChanged - text: #{text.inspect}"
  end


  # Called when main window is set fullscreen or set to original placement.
  # @param [Boolean] state +true+ set fullscreen, +false+ set to original
  #   placement.
  def swo_mw_onSwitchFullscreen(state)
    puts "swo_mw_onSwitchFullscreen - state: #{state}"
  end


  # Called when main window is maximized.
  def swo_mw_onMaximize
    puts "swo_mw_onMaximize"
  end


  # Called when main window is minimized.
  def swo_mw_onMinimize
    puts "swo_mw_onMinimize"
  end


  # Called when main window is set to default placement.
  def swo_mw_onRestore
    puts "swo_mw_onRestore"
  end


  # Called when main window is set foreground.
  def swo_mw_onActivate
    puts "swo_mw_onActivate"
  end


  # Called when main window looses focus.
  def swo_mw_onDeactivate
    puts "swo_mw_onDeactivate"
  end


  # Called after main window enters the moving or sizing modal loop.
  def swo_mw_onEnterSizeMove
    puts "swo_mw_onEnterSizeMove"
  end


  # Called after main window exits the moving or sizing modal loop.
  def swo_mw_onExitSizeMove
    puts "swo_mw_onExitSizeMove"
  end


  # Called when main window is moved or sized.
  # @param [Integer] x1 X position of the upper-left corner of the window.
  # @param [Integer] y1 Y position of the upper-left corner of the window.
  # @param [Integer] x1 X position of the lower-right corner of the window.
  # @param [Integer] y1 Y position of the lower-right corner of the window.
  def swo_mw_onSizeMove(x1,y1, x2,y2)
    puts "swo_mw_onSizeMove - pos1: (#{x1},#{y1}), pos2: (#{x2},#{y2})"
  end


  # Called when key is pressed.
  # @param [String] key Virtual key name
  # @param [Integer] val Virual key value
  def swo_mw_onKeyDown(key, val)
    puts "swo_mw_onKeyDown - key: #{key}, val: #{val}"
    AMS::Sketchup.remove_observer(self) if key == 'escape'
  end


  # Called when key is held down.
  # @param [String] key Virtual key name
  # @param [Integer] val Virual key value
  def swo_mw_onKeyExtended(key, val)
    puts "swo_mw_onKeyExtended - key: #{key}, val: #{val}"
  end


  # Called when key is released.
  # @param [String] key Virtual key name
  # @param [Integer] val Virual key value
  def swo_mw_onKeyUp(key, val)
    puts "swo_mw_onKeyUp - key: #{key}, val: #{val}"
  end


  # Called when menubar is set or removed.
  def swo_mb_onSetRemove(state)
    puts "swo_mb_onSetRemove - state: #{state}"
  end


  # Called when viewport border is set or removed.
  # @param [Boolean] state +true+ set, +false+ removed.
  def swo_vp_onSetRemoveClientEdge(state)
    puts "swo_vp_onSetRemoveClientEdge - state: #{state}"
  end


  # Called when viewport is sized.
  # @param [Integer] w The new width of the window.
  # @param [Integer] h The new height of the window.
  def swo_vp_onSize(w,h)
    puts "swo_vp_onSize - size: (#{w}, #{h})"
  end


  # Called when mouse enters the viewport client area.
  def swo_vp_onMouseEnter
    puts "swo_vp_onMouseEnter"
  end


  # Called when mouse exits the viewport client area.
  def swo_vp_onMouseLeave
    puts "swo_vp_onMouseLeave"
  end


  # Called when the viewport window is repainted. This callback is called often,
  # so be careful at what you put here.
  def swo_vp_onRepaint
    #puts "swo_vp_onRepaint"
    #UI.start_timer(0.01, false){
    #  win = AMS::Windows
    #  hwnd = AMS::Sketchup.viewport
    #  hdc = win::GetDC.call(hwnd)
    #  win::PaintDesktop.call(hdc)
    #  win::ReleaseDC.call(hwnd, hdc)
    #}
  end


  # Called when certain toolbar container is shown or hidden.
  # @param [Integer] bar +1+ - top, +2+ - bottom, +3+ - left, +4+ - right.
  # @param [Boolean] state +true+ - set visible, +false+ - set hidden.
  def swo_tbc_onVisibilityChanged(bar, state)
    puts "swo_tbc_onVisibilityChanged - bar: #{bar}, state #{state}"
  end


  # Called when scenesbar is shown or hidden.
  # @param [Boolean] state +true+ - set visible, +false+ - set hidden.
  def swo_scb_onVisibilityChanged(state)
    puts "swo_scb_onVisibilityChanged - state: #{state}"
  end


  # Called when statusbar is shown or hidden.
  # @param [Boolean] state +true+ - set visible, +false+ - set hidden.
  def swo_stb_onVisibilityChanged(state)
    puts "swo_stb_onVisibilityChanged - state: #{state}"
  end

end

unless file_loaded?(__FILE__)
  swo = AMS::Examples::SWO.new
  menu = UI.menu('Plugins')
  item = menu.add_item('SWO'){
    if swo.state
      AMS::Sketchup.remove_observer(swo)
    else
      AMS::Sketchup.add_observer(swo)
    end
  }
  menu.set_validation_proc(item){ swo.state ? MF_CHECKED : MF_UNCHECKED }
  file_loaded(__FILE__)
end
