# ------------------------------------------------------------------------------
#
#   Anton Synytsia
#   anton.synytsia@gmail.com
#
# ------------------------------------------------------------------------------

Sketchup.require 'ams_Lib/sketchup_window.rb'

# Scenes bar is SketchUp's child window that is responsible for holding the
# scene tabs/pages. It is usually positioned underneath the top toolbar
# container.
module AMS::Sketchup::Scenesbar

  class << self

    private

    def win
      AMS::Windows
    end

    public

    # Retrieves a handle to the main window's scenes-bar.
    # @return [Long] hWnd
    def hwnd
      AMS::Sketchup.scenesbar
    end

    alias handle hwnd


    # Modifies window's visibility state.
    # @param [Boolean] state Whether to show or hide the window.
    # @param [Boolean] refresh Whether to refresh after the operation.
    # @return [Boolean] Whether window's state was changed.
    def show(state = true, refresh = true)
      state = (state == true)
      return false if (state and empty?) or (state == visible?)
      cmd = state ? 4 : 0
      win::ShowWindow.call(hwnd, cmd)
      AMS::Sketchup.refresh if refresh == true
      true
    end


    # Determine whether the window is visible.
    # @return [Boolean] +true+ if visible, +false+ if hidden.
    def visible?
      win::IsWindowVisible.call(hwnd) == 1
    end


    # Determines whether scenesbar has one or more pages.
    # @return [Boolean]
    def filled?
      Sketchup.active_model.pages.size != 0
    end


    # Opposite of {filled?}.
    # @return [Boolean]
    def empty?
      Sketchup.active_model.pages.size == 0
    end

  end # proxy class

end # module AMS::Sketchup::ScenesBar

AMS::Lib.file_loaded(__FILE__)
